@@ -52,22 +52,55 @@ def sync(last_date):
 
 
 @cmd.command()
-def notify():
+@click.option('--start-date', default=False)
+@click.option('--stop-date', default=False)
+def notify(start_date, stop_date):
     """Commande pour notifier les clients grand public \
     selon leur niveau de consommation"""
     click.echo('Récupération des données depuis Bluebase')
-    customers = Product_GP.all()
-    for customer in customers:
-        click.echo('Notification du client {}'.format(customer.msisdn))
-        response = customer.notify()
-        if not response:
-            click.echo("Pas de notification à envoyer")
-        else:
-            medium, percentage, status = response
-            msg = '{}: {}%'.format(medium, round(percentage))
-            if status:
-                msg = '{} ({})'.format(msg, 'Notification envoyée')
-            click.echo(msg)
+    msg_client = ' '
+    product_types = CONFIG['PRODUCT']['product_type'].split(',')
+    for product_type in product_types:
+        customers = Product_GP.all(product_type)
+        for customer in customers:
+            click.echo('Notification du client {}'.format(customer.ident))
+            url = core.database_url(**FUPDB_CREDENTIALS)
+            with records.Database(url) as db:
+                sql = "SELECT refnum, product FROM customer WHERE name=:name"
+                rows = db.query(sql, name=customer.ident.lower())
+                row = rows.first()
+                if not row and customer.type_ident.lower() == 'ident':
+                    msg_client += "Le client {name} n'existe pas.\n".format(
+                        name=customer.ident.lower()
+                        )
+                    click.echo('customer {} exist pas'.format(
+                        customer.ident.lower()
+                        ))
+                else:
+                    response = customer.notify(start_date, stop_date)
+                    if not response:
+                        click.echo("Pas de notification à envoyer")
+                    else:
+                        medium, percentage, status = response
+                        msg = '{}: {}%'.format(medium, round(percentage))
+                        if status:
+                            msg = '{} ({})'.format(msg, 'Notification envoyée')
+                        click.echo(msg)
+        if msg_client.strip() != '':
+            dest = CONFIG['ALERT']['to_1']
+            content = MIMEText(msg_client, 'plain', 'utf-8')
+            msg = MIMEMultipart()
+            msg['Subject'] = '[blueline] customer inconnu'
+            msg['From'] = CONFIG['ALERT']['from']
+            msg['To'] = CONFIG['ALERT']['to_1']
+            msg.attach(content)
+            s = smtplib.SMTP('localhost')
+            s.sendmail(
+                CONFIG['ALERT']['from'],
+                dest.split(','),
+                msg.as_string()
+                )
+            s.quit()
 
 
 @cmd.command()
