@@ -121,6 +121,11 @@ class Customer(object):
         customer_status = self.fup_status
         for policy_name in self.product.policies:
             status = customer_status.get(policy_name)
+            policy_name_tab = policy_name.rsplit('_', 1)
+            if policy_name_tab[1] == '2':
+                period = 'hc'
+            else:
+                period = 'hp'
             if status:
                 status = sorted(
                     status,
@@ -135,7 +140,10 @@ class Customer(object):
                             CONFIG['AIGUILLIER']['username'],
                             CONFIG['AIGUILLIER']['password']
                             ),
-                        params={'customer': self.name}
+                        params={
+                            'customer': self.name,
+                            'period': period
+                        }
                         )
                     url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
@@ -154,23 +162,24 @@ class Customer(object):
                             status=False
                             )
                     result = {
-                        'status': '200',
+                        'code': '200',
                         'message': 'défup reussit'
                         }
                 else:
                     result = {
-                            'status': '201',
+                            'code': '201',
                             'message': 'deja fupé'
                             }
             else:
                 result = {
-                        'status': '204',
+                        'code': '204',
                         'message': 'produit non fupé'
                         }
 
-            LOGS.logger.info("Defuper un client {}-{}".format(
+            LOGS.logger.info("Defuper un client {}-{}-{}".format(
                 self.name,
-                policy_name
+                policy_name,
+                period
                 ))
         return result
 
@@ -451,6 +460,11 @@ class Customer(object):
                         'details': day_details
                         }
                     )
+            policy_name_tab = policy_name.rsplit('_', 1)
+            if policy_name_tab[1] == '2':
+                info['period'] = 'hc'
+            else:
+                info['period'] = 'hp'
             info['sources'] = [
                 {
                     'source': source,
@@ -517,13 +531,18 @@ class Customer(object):
                             date_time=datetime.now(),
                             status=True
                             )
+                    LOGS.logger.info(info['name'])
+                    LOGS.logger.info(info['period'])
                     REST_CLIENT.post(
                         '/fup',
                         auth=(
                             CONFIG['AIGUILLIER']['username'],
                             CONFIG['AIGUILLIER']['password']
                             ),
-                        params={'customer': self.name}
+                        params={
+                            'customer': self.name,
+                            'period': info['period']
+                            }
                         )
                 elif info.get('fup_out'):  # libérer
                     url = core.database_url(**FUPDB_CREDENTIALS)
@@ -548,7 +567,10 @@ class Customer(object):
                             CONFIG['AIGUILLIER']['username'],
                             CONFIG['AIGUILLIER']['password']
                             ),
-                        params={'customer': self.name}
+                        params={
+                            'customer': self.name,
+                            'period': info['period']
+                            }
                         )
         return cdrs_by_policies
 
